==> jc-1.4.0.tar.gz: javax/crypto/CipherOutputStream.h <==
// public class javax.crypto.CipherOutputStream

// class file dependencies
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class dd878b079c781d52 javax_crypto_CipherOutputStream

// header file dependencies
// @dep_header java_io_FilterOutputStream

#include "java/io/FilterOutputStream.h"

#ifndef _JC_javax_crypto_CipherOutputStream_H_
#define _JC_javax_crypto_CipherOutputStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_crypto_Cipher$object;

// Typedefs
typedef struct _jc_javax_crypto_CipherOutputStream$sub_refs	_jc_javax_crypto_CipherOutputStream$sub_refs;
typedef struct _jc_javax_crypto_CipherOutputStream$sub_nonrefs	_jc_javax_crypto_CipherOutputStream$sub_nonrefs;
typedef struct _jc_javax_crypto_CipherOutputStream$refs	_jc_javax_crypto_CipherOutputStream$refs;
typedef struct _jc_javax_crypto_CipherOutputStream$nonrefs	_jc_javax_crypto_CipherOutputStream$nonrefs;
typedef struct _jc_javax_crypto_CipherOutputStream$object	_jc_javax_crypto_CipherOutputStream$object;

typedef struct _jc_javax_crypto_CipherOutputStream$fields_struct	_jc_javax_crypto_CipherOutputStream$fields_struct;
typedef const struct _jc_javax_crypto_CipherOutputStream$vmethods	_jc_javax_crypto_CipherOutputStream$vmethods;
typedef const struct _jc_javax_crypto_CipherOutputStream$vtable	_jc_javax_crypto_CipherOutputStream$vtable;
typedef const struct _jc_javax_crypto_CipherOutputStream$vtype	_jc_javax_crypto_CipherOutputStream$vtype;

// Class fields structure
struct _jc_javax_crypto_CipherOutputStream$fields_struct {
	jint	FIRST__5fTIME;
	jint	SEASONED;
	jint	SECOND__5fTIME;
};
extern _jc_javax_crypto_CipherOutputStream$fields_struct _jc_javax_crypto_CipherOutputStream$class_fields;

// Constructors
extern void _jc_javax_crypto_CipherOutputStream$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *, struct _jc_java_io_OutputStream$object *);
extern void _jc_javax_crypto_CipherOutputStream$method$_init$91ab559d46dbb5ca(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *, struct _jc_java_io_OutputStream$object *, struct _jc_javax_crypto_Cipher$object *);

// Virtual methods
extern void _jc_javax_crypto_CipherOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *);
extern void _jc_javax_crypto_CipherOutputStream$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *);
extern void _jc_javax_crypto_CipherOutputStream$method$process$20c177568351a84e(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *);
extern void _jc_javax_crypto_CipherOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *, jint);
extern void _jc_javax_crypto_CipherOutputStream$method$write$18e189e8fc25f121(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *, struct _jc_byte_array *);
extern void _jc_javax_crypto_CipherOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *, struct _jc_byte_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_CipherOutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_javax_crypto_CipherOutputStream$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_javax_crypto_CipherOutputStream$method_info$process$20c177568351a84e;
extern _jc_method _jc_javax_crypto_CipherOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_javax_crypto_CipherOutputStream$method_info$write$18e189e8fc25f121;
extern _jc_method _jc_javax_crypto_CipherOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_javax_crypto_CipherOutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *);
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *);
	void	(*process$20c177568351a84e)(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *);
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *, jint);
	void	(*write$18e189e8fc25f121)(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *, struct _jc_byte_array *);
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *, struct _jc_byte_array *, jint, jint);
};

// Vtable
struct _jc_javax_crypto_CipherOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_javax_crypto_CipherOutputStream$vmethods	javax_crypto_CipherOutputStream;
};

// Vtype
struct _jc_javax_crypto_CipherOutputStream$vtype {
	_jc_type			type;
	_jc_javax_crypto_CipherOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_CipherOutputStream$sub_refs {
	struct _jc_javax_crypto_Cipher$object	*cipher;
	_jc_object_array	*inBuffer;
	_jc_byte_array	*outBuffer;
};

// Reference instance fields (object)
struct _jc_javax_crypto_CipherOutputStream$refs {
    _jc_javax_crypto_CipherOutputStream$sub_refs	javax_crypto_CipherOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_CipherOutputStream$sub_nonrefs {
	jint	inLength;
	jint	state;
	jboolean	isStream;
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_CipherOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_javax_crypto_CipherOutputStream$sub_nonrefs	javax_crypto_CipherOutputStream;
};

// Object instance structure
struct _jc_javax_crypto_CipherOutputStream$object {
	_jc_javax_crypto_CipherOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_CipherOutputStream$vtype	*vtype;
	_jc_javax_crypto_CipherOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_CipherOutputStream$vtype _jc_javax_crypto_CipherOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_CipherOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_CipherOutputStream$class_object;

#endif	/* _JC_javax_crypto_CipherOutputStream_H_ */

==> jc-1.4.6.tar.gz: javax/crypto/CipherOutputStream.h <==
// public class javax.crypto.CipherOutputStream

// class file dependencies
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class dd878b079c781d52 javax_crypto_CipherOutputStream

// header file dependencies
// @dep_header java_io_FilterOutputStream

#include "java/io/FilterOutputStream.h"

#ifndef _JC_javax_crypto_CipherOutputStream_H_
#define _JC_javax_crypto_CipherOutputStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_crypto_Cipher$object;

// Typedefs
typedef struct _jc_javax_crypto_CipherOutputStream$sub_refs	_jc_javax_crypto_CipherOutputStream$sub_refs;
typedef struct _jc_javax_crypto_CipherOutputStream$sub_nonrefs	_jc_javax_crypto_CipherOutputStream$sub_nonrefs;
typedef struct _jc_javax_crypto_CipherOutputStream$refs	_jc_javax_crypto_CipherOutputStream$refs;
typedef struct _jc_javax_crypto_CipherOutputStream$nonrefs	_jc_javax_crypto_CipherOutputStream$nonrefs;
typedef struct _jc_javax_crypto_CipherOutputStream$object	_jc_javax_crypto_CipherOutputStream$object;

typedef struct _jc_javax_crypto_CipherOutputStream$fields_struct	_jc_javax_crypto_CipherOutputStream$fields_struct;
typedef const struct _jc_javax_crypto_CipherOutputStream$vmethods	_jc_javax_crypto_CipherOutputStream$vmethods;
typedef const struct _jc_javax_crypto_CipherOutputStream$vtable	_jc_javax_crypto_CipherOutputStream$vtable;
typedef const struct _jc_javax_crypto_CipherOutputStream$vtype	_jc_javax_crypto_CipherOutputStream$vtype;

// Class fields structure
struct _jc_javax_crypto_CipherOutputStream$fields_struct {
	jint	FIRST__5fTIME;
	jint	SEASONED;
	jint	SECOND__5fTIME;
};
extern _jc_javax_crypto_CipherOutputStream$fields_struct _jc_javax_crypto_CipherOutputStream$class_fields;

// Constructors
extern void _jc_javax_crypto_CipherOutputStream$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_javax_crypto_CipherOutputStream$method$_init$91ab559d46dbb5ca(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *, struct _jc_java_io_OutputStream$object *, struct _jc_javax_crypto_Cipher$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_crypto_CipherOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_javax_crypto_CipherOutputStream$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_javax_crypto_CipherOutputStream$method$process$20c177568351a84e(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_javax_crypto_CipherOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *, jint) _JC_JCNI_ATTR;
extern void _jc_javax_crypto_CipherOutputStream$method$write$18e189e8fc25f121(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_javax_crypto_CipherOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_CipherOutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_javax_crypto_CipherOutputStream$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_javax_crypto_CipherOutputStream$method_info$process$20c177568351a84e;
extern _jc_method _jc_javax_crypto_CipherOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_javax_crypto_CipherOutputStream$method_info$write$18e189e8fc25f121;
extern _jc_method _jc_javax_crypto_CipherOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_javax_crypto_CipherOutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *) _JC_JCNI_ATTR;
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *) _JC_JCNI_ATTR;
	void	(*process$20c177568351a84e)(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *) _JC_JCNI_ATTR;
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *, jint) _JC_JCNI_ATTR;
	void	(*write$18e189e8fc25f121)(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_javax_crypto_CipherOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_crypto_CipherOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_javax_crypto_CipherOutputStream$vmethods	javax_crypto_CipherOutputStream;
};

// Vtype
struct _jc_javax_crypto_CipherOutputStream$vtype {
	_jc_type			type;
	_jc_javax_crypto_CipherOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_CipherOutputStream$sub_refs {
	struct _jc_javax_crypto_Cipher$object	*cipher;
	_jc_object_array	*inBuffer;
	_jc_byte_array	*outBuffer;
};

// Reference instance fields (object)
struct _jc_javax_crypto_CipherOutputStream$refs {
    _jc_javax_crypto_CipherOutputStream$sub_refs	javax_crypto_CipherOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_CipherOutputStream$sub_nonrefs {
	jint	inLength;
	jint	state;
	jboolean	isStream;
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_CipherOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_javax_crypto_CipherOutputStream$sub_nonrefs	javax_crypto_CipherOutputStream;
};

// Object instance structure
struct _jc_javax_crypto_CipherOutputStream$object {
	_jc_javax_crypto_CipherOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_CipherOutputStream$vtype	*vtype;
	_jc_javax_crypto_CipherOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_CipherOutputStream$vtype _jc_javax_crypto_CipherOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_CipherOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_CipherOutputStream$class_object;

#endif	/* _JC_javax_crypto_CipherOutputStream_H_ */
